@@ -1,8 +1,6 @@
 'use strict'
 
 const debug = require('debug')('nock.common')
-const isPlainObject = require('lodash/isPlainObject')
-const set = require('lodash/set')
 const timers = require('timers')
 const url = require('url')
 const util = require('util')
@@ -72,16 +70,13 @@ function overrideRequests(newRequest) {
     debug('- overriding request for', proto)
 
     const moduleName = proto // 1 to 1 match of protocol and module is fortunate :)
-    const module = {
-      http: require('http'),
-      https: require('https'),
-    }[moduleName]
+    const module = require(proto)
     const overriddenRequest = module.request
     const overriddenGet = module.get
 
     if (requestOverrides[moduleName]) {
       throw new Error(
-        `Module's request already overridden for ${moduleName} protocol.`
+        `Module's request already overridden for ${moduleName} protocol.`,
       )
     }
 
@@ -126,7 +121,7 @@ function restoreOverriddenRequests() {
       module.request = request
       module.get = get
       debug('- restored request for', proto)
-    }
+    },
   )
   requestOverrides = {}
 }
@@ -206,11 +201,11 @@ function headersFieldNamesToLowerCase(headers, throwOnDuplicate) {
     if (lowerCaseHeaders[key] !== undefined) {
       if (throwOnDuplicate) {
         throw Error(
-          `Failed to convert header keys to lower case due to field name conflict: ${key}`
+          `Failed to convert header keys to lower case due to field name conflict: ${key}`,
         )
       } else {
         debug(
-          `Duplicate header provided in request: ${key}. Only the last value can be matched.`
+          `Duplicate header provided in request: ${key}. Only the last value can be matched.`,
         )
       }
     }
@@ -244,7 +239,7 @@ function headersInputToRawArray(headers) {
     // but throw an error if there aren't an even number of items in the array
     if (headers.length % 2) {
       throw new Error(
-        `Raw headers must be provided as an array with an even number of items. [fieldName, value, ...]`
+        `Raw headers must be provided as an array with an even number of items. [fieldName, value, ...]`,
       )
     }
     return [...headers]
@@ -260,7 +255,7 @@ function headersInputToRawArray(headers) {
   }
 
   throw new Error(
-    `Headers must be provided as an array of raw values, a Map, or a plain Object. ${headers}`
+    `Headers must be provided as an array of raw values, a Map, or a plain Object. ${headers}`,
   )
 }
 
@@ -568,17 +563,6 @@ const dataEqual = (expected, actual) => {
   return deepEqual(expected, actual)
 }
 
-/**
- * Converts flat objects whose keys use JSON path notation to nested objects.
- *
- * The input object is not mutated.
- *
- * @example
- * { 'foo[bar][0]': 'baz' } -> { foo: { bar: [ 'baz' ] } }
- */
-const expand = input =>
-  Object.entries(input).reduce((acc, [k, v]) => set(acc, k, v), {})
-
 /**
  * Performs a recursive strict comparison between two values.
  *
@@ -600,7 +584,7 @@ function deepEqual(expected, actual) {
 
   if (isPlainObject(expected) && isPlainObject(actual)) {
     const allKeys = Array.from(
-      new Set(Object.keys(expected).concat(Object.keys(actual)))
+      new Set(Object.keys(expected).concat(Object.keys(actual))),
     )
 
     return allKeys.every(key => deepEqual(expected[key], actual[key]))
@@ -665,10 +649,97 @@ function isRequestDestroyed(req) {
   )
 }
 
+/**
+ * Returns true if the given value is a plain object and not an Array.
+ * @param {*} value
+ * @returns {boolean}
+ */
+function isPlainObject(value) {
+  if (typeof value !== 'object' || value === null) return false
+
+  if (Object.prototype.toString.call(value) !== '[object Object]') return false
+
+  const proto = Object.getPrototypeOf(value)
+  if (proto === null) return true
+
+  const Ctor =
+    Object.prototype.hasOwnProperty.call(proto, 'constructor') &&
+    proto.constructor
+  return (
+    typeof Ctor === 'function' &&
+    Ctor instanceof Ctor &&
+    Function.prototype.call(Ctor) === Function.prototype.call(value)
+  )
+}
+
+const prototypePollutionBlockList = ['__proto__', 'prototype', 'constructor']
+const blocklistFilter = function (part) {
+  return prototypePollutionBlockList.indexOf(part) === -1
+}
+
+/**
+ * Converts flat objects whose keys use JSON path notation to nested objects.
+ *
+ * The input object is not mutated.
+ *
+ * @example
+ * { 'foo[bar][0]': 'baz' } -> { foo: { bar: [ 'baz' ] } }
+ */
+const expand = input => {
+  if (input === undefined || input === null) {
+    return input
+  }
+
+  const keys = Object.keys(input)
+
+  const result = {}
+  let resultPtr = result
+
+  for (let path of keys) {
+    const originalPath = path
+    if (path.indexOf('[') >= 0) {
+      path = path.replace(/\[/g, '.').replace(/]/g, '')
+    }
+
+    const parts = path.split('.')
+
+    const check = parts.filter(blocklistFilter)
+
+    if (check.length !== parts.length) {
+      return undefined
+    }
+    resultPtr = result
+    const lastIndex = parts.length - 1
+
+    for (let i = 0; i < parts.length; ++i) {
+      const part = parts[i]
+      if (i === lastIndex) {
+        if (Array.isArray(resultPtr)) {
+          resultPtr[+part] = input[originalPath]
+        } else {
+          resultPtr[part] = input[originalPath]
+        }
+      } else {
+        if (resultPtr[part] === undefined || resultPtr[part] === null) {
+          const nextPart = parts[i + 1]
+          if (/^\d+$/.test(nextPart)) {
+            resultPtr[part] = []
+          } else {
+            resultPtr[part] = {}
+          }
+        }
+        resultPtr = resultPtr[part]
+      }
+    }
+  }
+  return result
+}
+
 module.exports = {
   contentEncoding,
   dataEqual,
   deleteHeadersField,
+  expand,
   forEachHeader,
   formatQueryValue,
   headersArrayToObject,
