@@ -42,7 +42,7 @@ class InterceptedRequestRouter {
       // We use lower-case header field names throughout Nock.
       headers: common.headersFieldNamesToLowerCase(
         options.headers || {},
-        false
+        false,
       ),
     }
     this.interceptors = interceptors
@@ -89,7 +89,7 @@ class InterceptedRequestRouter {
       req.setHeader(
         // We use lower-case header field names throughout Nock.
         'authorization',
-        `Basic ${Buffer.from(options.auth).toString('base64')}`
+        `Basic ${Buffer.from(options.auth).toString('base64')}`,
       )
     }
 
@@ -297,16 +297,16 @@ class InterceptedRequestRouter {
     const requestBodyIsUtf8Representable =
       common.isUtf8Representable(requestBodyBuffer)
     const requestBodyString = requestBodyBuffer.toString(
-      requestBodyIsUtf8Representable ? 'utf8' : 'hex'
+      requestBodyIsUtf8Representable ? 'utf8' : 'hex',
     )
 
     const matchedInterceptor = interceptors.find(i =>
-      i.match(req, options, requestBodyString)
+      i.match(req, options, requestBodyString),
     )
 
     if (matchedInterceptor) {
       matchedInterceptor.scope.logger(
-        'interceptor identified, starting mocking'
+        'interceptor identified, starting mocking',
       )
 
       matchedInterceptor.markConsumed()
@@ -329,7 +329,7 @@ class InterceptedRequestRouter {
 
       // Try to find a hostname match that allows unmocked.
       const allowUnmocked = interceptors.some(
-        i => i.matchHostName(options) && i.options.allowUnmocked
+        i => i.matchHostName(options) && i.options.allowUnmocked,
       )
 
       if (allowUnmocked && req instanceof ClientRequest) {
