@@ -39,13 +39,13 @@ module.exports = class Interceptor {
       !uri.startsWith('*')
     ) {
       throw Error(
-        `Non-wildcard URL path strings must begin with a slash (otherwise they won't match anything) (got: ${uri})`
+        `Non-wildcard URL path strings must begin with a slash (otherwise they won't match anything) (got: ${uri})`,
       )
     }
 
     if (!method) {
       throw new Error(
-        'The "method" parameter is required for an intercept call.'
+        'The "method" parameter is required for an intercept call.',
       )
     }
 
@@ -67,10 +67,10 @@ module.exports = class Interceptor {
     //  We use lower-case header field names throughout Nock.
     this.reqheaders = common.headersFieldNamesToLowerCase(
       scope.scopeOptions.reqheaders || {},
-      true
+      true,
     )
     this.badheaders = common.headersFieldsArrayToLowerCase(
-      scope.scopeOptions.badheaders || []
+      scope.scopeOptions.badheaders || [],
     )
 
     this.delayBodyInMs = 0
@@ -118,7 +118,7 @@ module.exports = class Interceptor {
         // It's not very Javascript-y to throw an error for extra args to a function, but because
         // of legacy behavior, this error was added to reduce confusion for those migrating.
         throw Error(
-          'Invalid arguments. When providing a function for the first argument, .reply does not accept other arguments.'
+          'Invalid arguments. When providing a function for the first argument, .reply does not accept other arguments.',
         )
       }
       this.statusCode = null
@@ -152,7 +152,7 @@ module.exports = class Interceptor {
     // Including all the default headers is safe for our purposes because of the specific headers we introspect.
     // A more thoughtful process is used to merge the default headers when the response headers are finally computed.
     this.headers = common.headersArrayToObject(
-      this.rawHeaders.concat(this.scope._defaultReplyHeaders)
+      this.rawHeaders.concat(this.scope._defaultReplyHeaders),
     )
 
     //  If the content is not encoded we may need to transform the response body.
@@ -198,10 +198,16 @@ module.exports = class Interceptor {
     if (!fs) {
       throw new Error('No fs')
     }
-    const readStream = fs.createReadStream(filePath)
-    readStream.pause()
     this.filePath = filePath
-    return this.reply(statusCode, readStream, headers)
+    return this.reply(
+      statusCode,
+      () => {
+        const readStream = fs.createReadStream(filePath)
+        readStream.pause()
+        return readStream
+      },
+      headers,
+    )
   }
 
   // Also match request headers
@@ -236,7 +242,7 @@ module.exports = class Interceptor {
       "request header field doesn't match:",
       key,
       header,
-      reqHeader
+      reqHeader,
     )
     return false
   }
@@ -247,7 +253,7 @@ module.exports = class Interceptor {
       this.scope.logger(
         'attempting match %s, body = %s',
         stringify(options),
-        stringify(body)
+        stringify(body),
       )
     }
 
@@ -259,7 +265,7 @@ module.exports = class Interceptor {
 
     if (this.method !== method) {
       this.scope.logger(
-        `Method did not match. Request ${method} Interceptor ${this.method}`
+        `Method did not match. Request ${method} Interceptor ${this.method}`,
       )
       return false
     }
@@ -286,7 +292,7 @@ module.exports = class Interceptor {
     }
 
     const reqHeadersMatch = Object.keys(this.reqheaders).every(key =>
-      this.reqheaderMatches(options, key)
+      this.reqheaderMatches(options, key),
     )
 
     if (!reqHeadersMatch) {
@@ -299,13 +305,13 @@ module.exports = class Interceptor {
       !this.scope.scopeOptions.conditionally()
     ) {
       this.scope.logger(
-        'matching failed because Scope.conditionally() did not validate'
+        'matching failed because Scope.conditionally() did not validate',
       )
       return false
     }
 
     const badHeaders = this.badheaders.filter(
-      header => header in options.headers
+      header => header in options.headers,
     )
 
     if (badHeaders.length) {
@@ -322,7 +328,7 @@ module.exports = class Interceptor {
       const matchQueries = this.matchQuery({ search })
 
       this.scope.logger(
-        matchQueries ? 'query matching succeeded' : 'query matching failed'
+        matchQueries ? 'query matching succeeded' : 'query matching failed',
       )
 
       if (!matchQueries) {
@@ -369,7 +375,7 @@ module.exports = class Interceptor {
           "bodies don't match: \n",
           this._requestBody,
           '\n',
-          body
+          body,
         )
       }
     }
@@ -453,15 +459,6 @@ module.exports = class Interceptor {
   markConsumed() {
     this.interceptionCounter++
 
-    if (
-      (this.scope.shouldPersist() || this.counter > 0) &&
-      this.interceptionCounter > 1 &&
-      this.filePath
-    ) {
-      this.body = fs.createReadStream(this.filePath)
-      this.body.pause()
-    }
-
     remove(this)
 
     if (!this.scope.shouldPersist() && this.counter < 1) {
@@ -510,7 +507,7 @@ module.exports = class Interceptor {
       strFormattingFn = common.percentDecode
     }
 
-    if (queries instanceof URLSearchParams) {
+    if (queries instanceof URLSearchParams || typeof queries === 'string') {
       // Normalize the data into the shape that is matched against.
       // Duplicate keys are handled by combining the values into an array.
       queries = querystring.parse(queries.toString())
