@@ -39,7 +39,7 @@ function testNock(done) {
           expect(data).to.be.an.instanceOf(Buffer)
           expect(data.toString()).to.equal('Hello World!')
         })
-      }
+      },
     )
     .end()
 }
@@ -83,7 +83,7 @@ function nockBackWithFixtureLocalhost(mochaDone) {
           this.assertScopesFinished()
           nockDone()
           mochaDone()
-        }
+        },
       )
 
       request.on('error', () => expect.fail())
@@ -117,7 +117,7 @@ describe('Nock Back', () => {
 
   it('should throw an exception when a hook is not a function', () => {
     expect(() =>
-      nockBack('good_request.json', { before: 'not-a-function-innit' })
+      nockBack('good_request.json', { before: 'not-a-function-innit' }),
     ).to.throw('processing hooks must be a function')
   })
 
@@ -127,7 +127,7 @@ describe('Nock Back', () => {
         expect(nockDone).to.be.a('function')
         expect(context).to.be.an('object')
         done()
-      }
+      },
     )
   })
 
@@ -140,13 +140,31 @@ describe('Nock Back', () => {
     const fixturePath = path.join(nockBack.fixtures, fixtureName)
     nockBack(fixtureName, function (nockDone) {
       expect(() => this.assertScopesFinished()).to.throw(
-        `["GET http://www.example.test:80/"] was not used, consider removing ${fixturePath} to rerecord fixture`
+        `["GET http://www.example.test:80/"] was not used, consider removing ${fixturePath} to rerecord fixture`,
       )
       nockDone()
       done()
     })
   })
 
+  it('`query` returns all of the interceptors recorded to the cassette', done => {
+    nockBack('good_request.json').then(({ nockDone, context }) => {
+      const interceptor = context.query()
+      nockDone()
+      expect(interceptor.length).to.equal(1)
+      expect(interceptor[0].method).to.equal('GET')
+      expect(interceptor[0].uri).to.equal('/')
+      expect(interceptor[0].basePath).to.equal('http://www.example.test:80')
+      expect(interceptor[0].path).to.equal('/')
+      expect(interceptor[0].queries).to.be.null()
+      expect(interceptor[0].counter).to.equal(1)
+      expect(interceptor[0]).to.have.property('body')
+      expect(interceptor[0].statusCode).to.equal(200)
+      expect(interceptor[0].optional).to.equal(false)
+      done()
+    })
+  })
+
   describe('wild mode', () => {
     beforeEach(() => {
       nockBack.setMode('wild')
@@ -164,7 +182,7 @@ describe('Nock Back', () => {
 
     it(
       "shouldn't do anything when fixtures are present",
-      nockBackWithFixtureLocalhost
+      nockBackWithFixtureLocalhost,
     )
   })
 
@@ -186,7 +204,7 @@ describe('Nock Back', () => {
           response => {
             expect(response.statusCode).to.equal(217)
             done()
-          }
+          },
         )
 
         request.on('error', () => expect.fail())
@@ -224,7 +242,7 @@ describe('Nock Back', () => {
                 expect(fs.existsSync(fixtureLoc)).to.be.false()
                 done()
               })
-            }
+            },
           )
 
           request.on('error', () => expect.fail())
@@ -275,7 +293,7 @@ describe('Nock Back', () => {
               expect(response.statusCode).to.equal(217)
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               done()
-            }
+            },
           )
 
           request.on('error', () => expect.fail())
@@ -299,7 +317,7 @@ describe('Nock Back', () => {
                 nockDone()
 
                 const fixtureContent = JSON.parse(
-                  fs.readFileSync(fixtureLoc).toString('utf8')
+                  fs.readFileSync(fixtureLoc).toString('utf8'),
                 )
                 expect(fixtureContent).to.have.length(1)
 
@@ -314,7 +332,7 @@ describe('Nock Back', () => {
               })
 
               response.resume()
-            }
+            },
           )
 
           request.on('error', err => expect.fail(err.message))
@@ -342,7 +360,7 @@ describe('Nock Back', () => {
               expect(response.statusCode).to.equal(217)
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               done()
-            }
+            },
           )
 
           request.on('error', () => expect.fail())
@@ -357,7 +375,7 @@ describe('Nock Back', () => {
           .get('http://other.example.test', () => expect.fail())
           .on('error', err => {
             expect(err.message).to.equal(
-              'Nock: Disallowed net connect for "other.example.test:80/"'
+              'Nock: Disallowed net connect for "other.example.test:80/"',
             )
             nockDone()
             done()
@@ -398,7 +416,7 @@ describe('Nock Back', () => {
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               expect(this.scopes).to.be.empty()
               done()
-            }
+            },
           )
           request.on('error', () => expect.fail())
           request.end()
@@ -425,10 +443,10 @@ describe('Nock Back', () => {
               expect(response.statusCode).to.equal(217)
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               expect(fs.readFileSync(fixtureLoc, 'utf8')).to.equal(
-                'string-response'
+                'string-response',
               )
               done()
-            }
+            },
           )
           request.on('error', () => expect.fail())
           request.end()
@@ -454,7 +472,7 @@ describe('Nock Back', () => {
                   nockDone()
 
                   const fixtureContent = JSON.parse(
-                    fs.readFileSync(fixtureLoc).toString('utf8')
+                    fs.readFileSync(fixtureLoc).toString('utf8'),
                   )
 
                   expect(fixtureContent).to.have.length(1)
@@ -463,13 +481,13 @@ describe('Nock Back', () => {
                   done()
                 })
                 response.resume()
-              }
+              },
             )
 
             request.on('error', () => expect.fail())
             request.end()
           })
-        }
+        },
       )
     })
 
@@ -496,7 +514,7 @@ describe('Nock Back', () => {
       nockBack.setMode('update')
       fs.copyFileSync(
         path.resolve(fixturePath, 'wrong_uri.json'),
-        path.resolve(fixturePath, 'temp_wrong_uri.json')
+        path.resolve(fixturePath, 'temp_wrong_uri.json'),
       )
     })
 
@@ -521,7 +539,7 @@ describe('Nock Back', () => {
               expect(response.statusCode).to.equal(217)
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               done()
-            }
+            },
           )
 
           request.on('error', () => expect.fail())
@@ -545,7 +563,7 @@ describe('Nock Back', () => {
                 nockDone()
 
                 const fixtureContent = JSON.parse(
-                  fs.readFileSync(fixtureLoc).toString('utf8')
+                  fs.readFileSync(fixtureLoc).toString('utf8'),
                 )
                 expect(fixtureContent).to.have.length(1)
 
@@ -560,7 +578,7 @@ describe('Nock Back', () => {
               })
 
               response.resume()
-            }
+            },
           )
 
           request.on('error', err => expect.fail(err.message))
@@ -588,7 +606,7 @@ describe('Nock Back', () => {
               expect(response.statusCode).to.equal(217)
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               done()
-            }
+            },
           )
 
           request.on('error', () => expect.fail())
@@ -610,10 +628,10 @@ describe('Nock Back', () => {
               nockDone()
               expect(response.statusCode).to.equal(217)
               expect(
-                fs.existsSync(`${fixturePath}/temp_wrong_uri.json`)
+                fs.existsSync(`${fixturePath}/temp_wrong_uri.json`),
               ).to.be.true()
               done()
-            }
+            },
           )
 
           request.on('error', () => expect.fail())
@@ -625,7 +643,7 @@ describe('Nock Back', () => {
     it("shouldn't load recorded tests", done => {
       fs.copyFileSync(
         path.resolve(fixturePath, 'good_request.json'),
-        path.resolve(fixturePath, 'temp_good_request.json')
+        path.resolve(fixturePath, 'temp_good_request.json'),
       )
       nockBack('temp_good_request.json', function (nockDone) {
         expect(this.scopes).to.have.lengthOf.at.least(0)
@@ -662,7 +680,7 @@ describe('Nock Back', () => {
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               expect(this.scopes).to.be.empty()
               done()
-            }
+            },
           )
           request.on('error', () => expect.fail())
           request.end()
@@ -689,10 +707,10 @@ describe('Nock Back', () => {
               expect(response.statusCode).to.equal(217)
               expect(fs.existsSync(fixtureLoc)).to.be.true()
               expect(fs.readFileSync(fixtureLoc, 'utf8')).to.equal(
-                'string-response'
+                'string-response',
               )
               done()
-            }
+            },
           )
           request.on('error', () => expect.fail())
           request.end()
@@ -718,7 +736,7 @@ describe('Nock Back', () => {
                   nockDone()
 
                   const fixtureContent = JSON.parse(
-                    fs.readFileSync(fixtureLoc).toString('utf8')
+                    fs.readFileSync(fixtureLoc).toString('utf8'),
                   )
 
                   expect(fixtureContent).to.have.length(1)
@@ -727,13 +745,13 @@ describe('Nock Back', () => {
                   done()
                 })
                 response.resume()
-              }
+              },
             )
 
             request.on('error', () => expect.fail())
             request.end()
           })
-        }
+        },
       )
     })
 
@@ -761,12 +779,12 @@ describe('Nock Back', () => {
           host: 'other.example.test',
           path: '/',
         },
-        () => expect.fail('Should not come here!')
+        () => expect.fail('Should not come here!'),
       )
 
       req.on('error', err => {
         expect(err.message.trim()).to.equal(
-          'Nock: Disallowed net connect for "other.example.test:80/"'
+          'Nock: Disallowed net connect for "other.example.test:80/"',
         )
         done()
       })
